@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from pythonperlin.perlin import perlin, extend
+from pythonperlin.perlin import perlin, extend2d
 from pkg_resources import get_distribution
 
 __version__ = get_distribution('pythonperlin').version
\ No newline at end of file
